import { Subject } from 'rxjs';
import { EditViewBase } from '@/studio-core';
import EAMPlanService from '@/service/eamplan/eamplan-service';
import EAMPlanAuthService from '@/authservice/eamplan/eamplan-auth-service';
import EditViewEngine from '@engine/view/edit-view-engine';
import EAMPlanUIService from '@/uiservice/eamplan/eamplan-ui-service';

/**
 * 维护计划主信息视图基类
 *
 * @export
 * @class EAMPlanInfo_MainViewBase
 * @extends {EditViewBase}
 */
export class EAMPlanInfo_MainViewBase extends EditViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMPlanInfo_MainViewBase
     */
    protected appDeName: string = 'eamplan';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMPlanInfo_MainViewBase
     */
    protected appDeKey: string = 'eamplanid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMPlanInfo_MainViewBase
     */
    protected appDeMajor: string = 'eamplanname';

    /**
     * 实体服务对象
     *
     * @type {EAMPlanService}
     * @memberof EAMPlanInfo_MainViewBase
     */
    protected appEntityService: EAMPlanService = new EAMPlanService;

    /**
     * 实体权限服务对象
     *
     * @type EAMPlanUIService
     * @memberof EAMPlanInfo_MainViewBase
     */
    public appUIService: EAMPlanUIService = new EAMPlanUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMPlanInfo_MainViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMPlanInfo_MainViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamplan.views.info_mainview.caption',
        srfTitle: 'entities.eamplan.views.info_mainview.title',
        srfSubTitle: 'entities.eamplan.views.info_mainview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMPlanInfo_MainViewBase
     */
    protected containerModel: any = {
        view_form: { name: 'form', type: 'FORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '77a4e1c6dd284b75b0db1c44937f3d8b';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMPlanInfo_MainViewBase
     */
    public engine: EditViewEngine = new EditViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMPlanInfo_MainViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            form: this.$refs.form,
            p2k: '0',
            keyPSDEField: 'eamplan',
            majorPSDEField: 'eamplanname',
            isLoadDefault: true,
        });
    }

    /**
     * form 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMPlanInfo_MainViewBase
     */
    public form_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'save', $event);
    }

    /**
     * form 部件 remove 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMPlanInfo_MainViewBase
     */
    public form_remove($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'remove', $event);
    }

    /**
     * form 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMPlanInfo_MainViewBase
     */
    public form_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'load', $event);
    }


}