import { Subject } from 'rxjs';
import { TabExpViewBase } from '@/studio-core';
import EAMPlanService from '@/service/eamplan/eamplan-service';
import EAMPlanAuthService from '@/authservice/eamplan/eamplan-auth-service';
import TabExpViewEngine from '@engine/view/tab-exp-view-engine';
import EAMPlanUIService from '@/uiservice/eamplan/eamplan-ui-service';

/**
 * 维护计划信息视图基类
 *
 * @export
 * @class EAMPlanInfoViewBase
 * @extends {TabExpViewBase}
 */
export class EAMPlanInfoViewBase extends TabExpViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMPlanInfoViewBase
     */
    protected appDeName: string = 'eamplan';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMPlanInfoViewBase
     */
    protected appDeKey: string = 'eamplanid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMPlanInfoViewBase
     */
    protected appDeMajor: string = 'eamplanname';

    /**
     * 实体服务对象
     *
     * @type {EAMPlanService}
     * @memberof EAMPlanInfoViewBase
     */
    protected appEntityService: EAMPlanService = new EAMPlanService;

    /**
     * 实体权限服务对象
     *
     * @type EAMPlanUIService
     * @memberof EAMPlanInfoViewBase
     */
    public appUIService: EAMPlanUIService = new EAMPlanUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMPlanInfoViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMPlanInfoViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamplan.views.infoview.caption',
        srfTitle: 'entities.eamplan.views.infoview.title',
        srfSubTitle: 'entities.eamplan.views.infoview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMPlanInfoViewBase
     */
    protected containerModel: any = {
        view_tabexppanel: { name: 'tabexppanel', type: 'TABEXPPANEL' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '66df4099ca35ed7c25fe15aca40ea3a5';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMPlanInfoViewBase
     */
    public engine: TabExpViewEngine = new TabExpViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMPlanInfoViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            keyPSDEField: 'eamplan',
            majorPSDEField: 'eamplanname',
            isLoadDefault: true,
        });
    }


}