import { Subject } from 'rxjs';
import { PickupViewBase } from '@/studio-core';
import EAMPlanService from '@/service/eamplan/eamplan-service';
import EAMPlanAuthService from '@/authservice/eamplan/eamplan-auth-service';
import PickupViewEngine from '@engine/view/pickup-view-engine';
import EAMPlanUIService from '@/uiservice/eamplan/eamplan-ui-service';

/**
 * 维护计划数据选择视图视图基类
 *
 * @export
 * @class EAMPlanPickupViewBase
 * @extends {PickupViewBase}
 */
export class EAMPlanPickupViewBase extends PickupViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMPlanPickupViewBase
     */
    protected appDeName: string = 'eamplan';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMPlanPickupViewBase
     */
    protected appDeKey: string = 'eamplanid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMPlanPickupViewBase
     */
    protected appDeMajor: string = 'eamplanname';

    /**
     * 实体服务对象
     *
     * @type {EAMPlanService}
     * @memberof EAMPlanPickupViewBase
     */
    protected appEntityService: EAMPlanService = new EAMPlanService;

    /**
     * 实体权限服务对象
     *
     * @type EAMPlanUIService
     * @memberof EAMPlanPickupViewBase
     */
    public appUIService: EAMPlanUIService = new EAMPlanUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMPlanPickupViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMPlanPickupViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamplan.views.pickupview.caption',
        srfTitle: 'entities.eamplan.views.pickupview.title',
        srfSubTitle: 'entities.eamplan.views.pickupview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMPlanPickupViewBase
     */
    protected containerModel: any = {
        view_pickupviewpanel: { name: 'pickupviewpanel', type: 'PICKUPVIEWPANEL' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'f38b93e7294aee1966d727940e0852f4';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMPlanPickupViewBase
     */
    public engine: PickupViewEngine = new PickupViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMPlanPickupViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            pickupviewpanel: this.$refs.pickupviewpanel,
            keyPSDEField: 'eamplan',
            majorPSDEField: 'eamplanname',
            isLoadDefault: true,
        });
    }

    /**
     * pickupviewpanel 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMPlanPickupViewBase
     */
    public pickupviewpanel_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'selectionchange', $event);
    }

    /**
     * pickupviewpanel 部件 activated 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMPlanPickupViewBase
     */
    public pickupviewpanel_activated($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'activated', $event);
    }

    /**
     * pickupviewpanel 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMPlanPickupViewBase
     */
    public pickupviewpanel_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'load', $event);
    }


}