import { Subject } from 'rxjs';
import { DashboardViewBase } from '@/studio-core';
import EAMPlanService from '@/service/eamplan/eamplan-service';
import EAMPlanAuthService from '@/authservice/eamplan/eamplan-auth-service';
import PortalViewEngine from '@engine/view/portal-view-engine';
import EAMPlanUIService from '@/uiservice/eamplan/eamplan-ui-service';

/**
 * 维护计划主信息看板视图基类
 *
 * @export
 * @class EAMPlanSummaryViewBase
 * @extends {DashboardViewBase}
 */
export class EAMPlanSummaryViewBase extends DashboardViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMPlanSummaryViewBase
     */
    protected appDeName: string = 'eamplan';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMPlanSummaryViewBase
     */
    protected appDeKey: string = 'eamplanid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMPlanSummaryViewBase
     */
    protected appDeMajor: string = 'eamplanname';

    /**
     * 实体服务对象
     *
     * @type {EAMPlanService}
     * @memberof EAMPlanSummaryViewBase
     */
    protected appEntityService: EAMPlanService = new EAMPlanService;

    /**
     * 实体权限服务对象
     *
     * @type EAMPlanUIService
     * @memberof EAMPlanSummaryViewBase
     */
    public appUIService: EAMPlanUIService = new EAMPlanUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMPlanSummaryViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMPlanSummaryViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamplan.views.summaryview.caption',
        srfTitle: 'entities.eamplan.views.summaryview.title',
        srfSubTitle: 'entities.eamplan.views.summaryview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMPlanSummaryViewBase
     */
    protected containerModel: any = {
        view_dashboard: { name: 'dashboard', type: 'DASHBOARD' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '6e69be88d76554770ec8448800b6881d';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMPlanSummaryViewBase
     */
    public engine: PortalViewEngine = new PortalViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMPlanSummaryViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            dashboard: this.$refs.dashboard,
            keyPSDEField: 'eamplan',
            majorPSDEField: 'eamplanname',
            isLoadDefault: true,
        });
    }

    /**
     * dashboard 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMPlanSummaryViewBase
     */
    public dashboard_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('dashboard', 'load', $event);
    }


}